alligator 0.7.1
===============

:date: 2015-01-02

This release adds lots of documentation & release notes, as well as bugfixes to
make ``Workers`` less unnecessarily busy & fixes argument handling in
``latergator.py``.


Features
--------

* Tutorial improvements. (SHA: 981503a, SHA: c3b26ee & SHA: 34fe5ab)
* Added the Best Practices docs. (SHA: 0d9ea2e)
* Filled in the Extending docs. (SHA: b0cf130, SHA: 1d472d5 & SHA: 8eb158c)


Bugfixes
--------

* Eventually fixed Travis CI support. (SHA: f264b59, SHA: a8833d8, SHA: 3f74b25,
  SHA: 3968cef & SHA: f6358e4)
* Fixed how unnecessarily busy ``Worker.run_forever()`` was. (SHA: 7b242fc)
* Fixed the argument handling in ``latergator.py``. (SHA: 18c5e0a)
